@@ -16,7 +16,7 @@ def calcresid(result):
         resid.append(results.data[i] - results.best_fit[i])
     return np.array(resid)
 
-def fit_pandas_GUI(dfs_info=None, show_text_col = False, **kwargs):
+def fit_pandas_GUI(df_info=None, show_text_col = False, **kwargs):
     """
     If passed no parameters this will look for all the dataframes in the user
     namespace and make them available for plotting. Once a
@@ -28,23 +28,28 @@ def fit_pandas_GUI(dfs_info=None, show_text_col = False, **kwargs):
 
     If you wish to allow only certain dataframes or have them show up as
     user friendly names in the menus provide that information in the first
-    paramater dfs_info.
+    paramater df_info.
 
     To allow inclusion of text columns pass True for show_text_col.
 
     :param bool show_text_col: (default = False). When True columns
     containing text will be shown.
 
-    :param list dfs_info: List of Lists [[object,globalname,
+    :param list df_info: List of Lists [[object,globalname,
     userfriendly]],..]
       * object -- pandas.DataFrame
       * globalname -- string name of the object in the user global name space.
       * userfriendly -- string name to display for user selection.
+      
     :keyword string figname: string used to override default python name for
     figure.
 
     :keyword string fitname: string used to override default python name for
     fit.
+    
+    :keyword bool findframes: default = True. If set to false and dataframes
+    are passed in dfs_info, will not search for dataframes in the user
+    namespace.
     """
     from ipywidgets import Layout, Box, HBox, VBox, GridBox, Tab, \
         Accordion, Dropdown, Label, Text, Button, Checkbox, FloatText, \
@@ -64,11 +69,15 @@ def fit_pandas_GUI(dfs_info=None, show_text_col = False, **kwargs):
     import JPSLUtils
     from lmfit import models
 
-    if dfs_info == None:
-        from .utils import find_pandas_dataframe_names
-        from IPython import get_ipython
-        global_dict = get_ipython().user_ns
-        dfs_info = []
+    from .utils import find_pandas_dataframe_names
+    from IPython import get_ipython
+    global_dict = get_ipython().user_ns
+    dfs_info = []
+    if isinstance(df_info,list):
+        for k in df_info:
+            dfs_info.append(k)
+    findframes = kwargs.pop('findframes',True)
+    if findframes:
         for k in find_pandas_dataframe_names():
             dfs_info.append([global_dict[k],k,k])
     friendly_to_globalname = {k[2]:k[1] for k in dfs_info}
@@ -668,12 +677,21 @@ def fit_pandas_GUI(dfs_info=None, show_text_col = False, **kwargs):
     range_plot_hilight_size = 20
     ranges=[]
     def update_range_point(trace, points, selector):
-        if len(trace['marker']['color'])!=len(trace['x']):
-            c = [range_plot_line_color]*len(trace['x'])
+        # size and color must be done separately as they may not be updated
+        # in sync.
+        try:
+            from collections.abc import Iterable
+        except ImportError(e):
+            from collections import Iterable            
+        if not isinstance(trace['marker']['size'],Iterable):
             s = [range_plot_marker_size]*len(trace['x'])
         else:
-            c = list(trace['marker']['color'])
             s = list(trace['marker']['size'])
+        if (not isinstance(trace['marker']['color'],Iterable)) or isinstance(
+                trace['marker']['color'],str):
+            c = [range_plot_line_color]*len(trace['x'])
+        else:
+            c = list(trace['marker']['color'])
         for i in points.point_inds:
             if selector.ctrl:
                 c[i]=range_plot_line_color
